/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include "../main.h"
#include "ads112u04.h"
#include "ads8881.h"
#include "ads7142.h"

void (*adc_init_fp)(void) = 0;
long int (*adc_get_fp)(void) = 0;

void adc_init(void){
    switch(config[config_id].adc_options){
    case ADS112U04:
        adc_init_fp = ads112_init;
        adc_get_fp = ads112_gettc;
        ads112_raw = &adc_raw;
        break;
    case ADS8881:
    	adc_init_fp = ads8881_init;
    	adc_get_fp = ads8881_gettc;
    	ads8881_raw = &adc_raw;
    	break;

    case ADS7142:
        adc_init_fp = ads7142_init;
		adc_get_fp = ads7142_gettc;
		ads7142_raw = &adc_raw;
		break;
    }

    if(adc_init_fp)
    	adc_init_fp();
}

long int adc_get(void){
	if(adc_get_fp)
		return adc_get_fp();
	else
		return 0;
}


