/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include "i2c.h"
#include "../main.h"

#define OP_READREG  0x10
#define OP_WRITEREG  0x08

#define REG_ACCUMULATOR_STATUS 	0x02
#define REG_ACC_CH0_LSB         0x08
#define REG_ACC_CH0_MSB         0x09
#define REG_ACC_CH1_LSB         0x0a
#define REG_ACC_CH1_MSB         0x0b
#define REG_OFFSET_CAL			0x15
#define REG_OPMODE_SEL          0x1c
#define REG_START_SEQUENCE      0x1e
#define REG_OSC_SEL             0x18
#define REG_nCLK_SEL            0x19
#define REG_AUTO_SEQ_CHEN       0x20
#define REG_CHANNEL_INPUT_CFG   0x24
#define REG_ACC_EN              0x30

long *ads7142_raw = 0;

static int read(int reg){
	int nok=1;
	int temp=0x100;
	char buf[2] = {OP_READREG, reg};
	char ret[2] = {0, 0};
	while(nok){
		i2c_start2(0x1f, 0);
		i2c_senddata(buf, 2);
		i2c_stop();
		i2c_start2(0x1f, 1);
		i2c_readdata(ret, 2);
		if(temp == ret[0]) nok = 0;
		temp = ret[0];
	}
	return ret[0];
}

static void write(int reg, int value){
	char buf[3] = {OP_WRITEREG, reg, value};
	i2c_start2(0x1f, 0);
	i2c_senddata(buf, 3);
	i2c_stop();
}

void ads7142_init(void){
	i2c_init();

	write(REG_OSC_SEL, 0x01); //low power osc
	write(REG_nCLK_SEL, 255); //nCLK_SEL

	write(REG_CHANNEL_INPUT_CFG, 0);
    write(REG_OPMODE_SEL, 7); //high precision mode
    write(REG_AUTO_SEQ_CHEN, 1); //channel 0 selected
    write(REG_ACC_EN, 0x0f); // enable acc
   // write(REG_OFFSET_CAL, 0x01);
    __delay_cycles(50000);
}

void ads_start(int p){
	int i;

	if(p == 0){ // convert only channel 0
		write(REG_AUTO_SEQ_CHEN, 1); //channel
		write(REG_START_SEQUENCE, 1); //start seq

		while(read(REG_ACCUMULATOR_STATUS) < 15)
			__delay_cycles(50000);

		__delay_cycles(50000);
		__delay_cycles(50000);
		__delay_cycles(50000);
		__delay_cycles(50000);

	}
	if(p == 1){
		write(REG_AUTO_SEQ_CHEN, 3); //channel
		write(REG_START_SEQUENCE, 1); //start seq

		while(read(REG_ACCUMULATOR_STATUS) < 15)
			__delay_cycles(50000);

		for(i=0;i<3; i++){
			__delay_cycles(50000);
			__delay_cycles(50000);
			__delay_cycles(50000);
			__delay_cycles(50000);
		}
	}
}

unsigned int ads_getch(int c){
	int value;
	//write(REG_START_SEQUENCE, 1); //start seq
	if(c == 0){
		value = read(REG_ACC_CH0_MSB);
		value <<= 8;
		value |= read(REG_ACC_CH0_LSB);
		return value;
	}else if(c == 1){
		value = read(REG_ACC_CH1_MSB);
		value <<= 8;
		value |= read(REG_ACC_CH1_LSB);
		return value;
	}
	return 0;
}


long ads7142_gettc(void){
	long value;
	long ch0, ch1;


    switch(config[config_id].tc_frontend){
    	case OPV:
    		ads_start(0);
    		*ads7142_raw = ads_getch(0);
    		value = (*ads7142_raw*25000UL) / 65535UL;
    		value += 7950; //needs calibration R33 R36
    		value /= (0.341*2); // need calibration R41 R43 - R38 R42
    		value -= 41000;  // need calibration R37 R39
    		break;

    	case INA:
    		ads_start(1);
    		ch0 = ads_getch(0);
    		ch1 = ads_getch(1);
    		*ads7142_raw = ch0 - ch1;
    	//	if(*ads7142_raw < -1000)
    	//		while(1);
    	    value = (*ads7142_raw*2500000.0) / 65535.0;
    	    value /= 33.36;

    	   // value = value/1.0017+97.681; //correction values for board 1

    	    break;
    }
    return value;
}

