/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include "spi.h"
#include <msp430.h>
#include "../main.h"

#define CONVST	(1<<4)
#define SCLK	(1<<5)
#define MISO	(1<<6)
#define MOSI	(1<<7)

long *ads8881_raw = 0;

void ads8881_init(void){
	P1DIR |= CONVST | SCLK | MOSI;
	P1DIR &= ~MISO;
	P1REN |= MISO;
	P1OUT |= MISO; // Enable Pull up on MISO
	P1OUT |= MOSI|SCLK;
	P1OUT &= ~(CONVST);

}

long ads8881_getraw(void){
	long temp=0;
	int i;
	// see datasheet Figure 51: 3 wire cs mode

	P1OUT &= ~CONVST;
	P1OUT |= SCLK;
	for(i=0;i<18;i++){
		P1OUT &= ~(SCLK);
		temp |= (P1IN & MISO) ? 1 : 0;
		temp <<= 1;
		P1OUT |= SCLK;
	}
	P1OUT |= CONVST;
	temp <<= 12;
	temp /= 8192;
	return temp;
}

long ads8881_gettc(void){
	int i;
	int j;
	long sum=0;
	long sum2=0;

	for(j=0;j<1;j++){
		for(i=0;i<1;i++){
			sum += ads8881_getraw();
		}
		sum /= 1;
		sum2 += sum;
		sum = 0;
	}
	sum2 /= 1;
	*ads8881_raw = sum2;

	    switch(config[config_id].tc_frontend){
    	case OPV:
    		return sum2; //todo
    	case INA:
    		return ((sum2*(2500000/40))/262144);
	    }



}
