/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include <msp430.h>
#include <stdio.h>
#include <stdarg.h>
#include "vt100.h"

void uart0_init(void){ //9600 connected to ads112u04
    P1SEL0 |= (1<<6)|(1<<7);

    UCA0CTLW0 |= UCSWRST;
    UCA0CTLW0 |= UCSSEL__SMCLK;
    UCA0BR0 = 52;                             // 8000000/16/9600
    UCA0BR1 = 0x00;
    UCA0MCTLW = 0x4900 | UCOS16 | UCBRF_1;
    UCA0CTLW0 &= ~UCSWRST;                    // Initialize eUSCI
}

void uart0_putc(char c){
    while(!(UCA0IFG&UCTXIFG));
    UCA0TXBUF = c;
}

int uart0_data_available(void){
    return UCA0IFG&UCRXIFG;
}

int uart0_getc(void){
    if(UCA0IFG&UCRXIFG){
        return UCA0RXBUF;
    }else
        return -1;
}

void uart1_init(void){ //115200 connected to PC
    P4SEL0 |= (1<<2)|(1<<3);


    UCA1CTLW0 |= UCSWRST;
    UCA1CTLW0 |= UCSSEL__SMCLK;
    UCA1BR0 = 4;
    UCA1BR1 = 0x00;
    UCA1MCTLW = 0x5500 | UCOS16 | UCBRF_5;
    UCA1CTLW0 &= ~UCSWRST;
    UCA1IE |= UCRXIE;
    __enable_interrupt();
}

void uart1_putc(char c){
    while(!(UCA1IFG&UCTXIFG));
    UCA1TXBUF = c;
}

void uart1_puts(char *s){
    while(*s)
        uart1_putc(*s++);
}

int uart1_getc(void){
    if(UCA1IFG&UCRXIFG){
        return UCA1RXBUF;
    }else
        return -1;
}

void uart_printf(const char * format, ...){
    char buffer[64];
    va_list args;
    va_start(args, format);
    vsprintf(buffer, format, args);
    uart1_puts(buffer);
    va_end(args);
}

#pragma vector=USCI_A1_VECTOR
__interrupt void uscia_isr(void){
	if(UCA1IFG & UCRXIFG){
		UCA1IFG &= ~UCRXIFG;
		menu_input(UCA1RXBUF);
	}
}
