/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

#include <msp430.h> 
#include <stdio.h>
#include <string.h>
#include <limits.h>
#include "main.h"
#include "drv/uart.h"
#include "drv/vt100.h"
#include "drv/adc.h"
#include "drv/clock.h"
#include "drv/cjc.h"
#include "drv/tc.h"

const struct config_struct config[6] = {
                                 {"OPV 8881", TMP117|LMT01, ADS8881, OPV, 2},
                                 {"INA 7142", TMP117|LMT01, ADS7142, INA, 2},
                                 {"INA 8881", TMP117|LMT01, ADS8881, INA, 2},
                                 {"RTD 112", RTD|ADS112, ADS112U04, INT, 2},
                                 {"LMT70", TMP235|ADS112|LMT70, ADS112U04, INT, 4},
                                 {"OPV 7142", TMP117|LMT01, ADS7142, OPV, 2},
};
const char adc_names[3][10] = {"ADS112U04", "ADS7142", "ADS8881"};
const char cjc_names[6][10] = {"TMP117", "LMT70", "TMP235", "RTD", "LMT01", "ADS112U04"};

unsigned int config_id; // state of r65, r66 r109 to identify board
char adc_name[10];
char cjc_name[4][10];
long adc_raw;
long cjc_raw[4];
long adc_value;
int cjc_value[4];
int cjc_volt[4];
int cjc_temp[4];
int tc_temp;
int terminal_log=0;

int main(void)
{
    int i;
    int j;

    long avg_buf[16];
    long avg=0;
	int avg_old;
	long min=LONG_MAX;
	long max=LONG_MIN;
	int counter=0;


	WDTCTL = WDTPW | WDTHOLD;	// stop watchdog timer
	PM5CTL0 &= ~LOCKLPM5;
	clock_init_8();
	uart1_init();

	P6REN |= 0x3;
	P4REN |= 0x80;
	P6OUT |= 0x3;
	P4OUT |= 0x80;
	config_id = (P4IN & 0x80);
	config_id >>= 7;
	config_id |= ((P6IN & 0x3) << 1);
	config_id = ~config_id & 0x7;
	strcpy(adc_name, adc_names[config[config_id].adc_options]);

	j = 0;
	for(i=0;i<8;i++){
	    if(config[config_id].cjc_options & (1<<i)){
	        strcpy(cjc_name[j++], cjc_names[i]);
	    }
	}

	vt100_init();
	menu_init();
	//uart_printf("Config: %d\n", config_id);
	adc_init();
	cjc_init();

	while(1){
	   /* uart_printf("%d",  (short)adc_get());
	    for(i=0;i<8;i++){
	        if(config[config_id].cjc_options & (1<<i)){
	            uart_printf("\t %d", cjc_get(1<<i));
	        }
	    }
	    uart_printf("\r\n");*/
		adc_value = adc_get();
		tc_temp = voltToTemp(adc_value);
		j = 0;
		for (i = 0; i < 8; i++) {
			if (config[config_id].cjc_options & (1 << i)) {
				cjc_value[j] = cjc_get(1 << i);
				cjc_volt[j] = TempToVolt(cjc_value[j]);
				cjc_temp[j] = voltToTemp(adc_value + cjc_volt[j]);
				j++;
			}
		}
//#define TESTMODE
#ifndef TESTMODE
		if(terminal_log){
			if(adc_value < min) min = adc_value;
			if(adc_value > max) max = adc_value;

			for(i=15;i>0;i--)
				avg_buf[i] = avg_buf[i-1];

			avg_buf[0] = adc_value;

			avg = 0;
			for(i=0;i<16;i++)
				avg += avg_buf[i];

			avg /= 16;

			uart_printf("%ld %ld %ld %ld\r\n", min, avg, max, adc_value);
		}else{
			min=LONG_MAX;
			max=LONG_MIN;
			menu_update_all();
		}
#else
		uart_printf("%ld %ld %ld %ld\r\n", adc_raw, cjc_raw[0], cjc_raw[1], cjc_raw[2]);
#endif
	}

	return 0;
}
